@@ -1,5 +1,5 @@
 package App::TeleGramma::BotAction::Listen;
-$App::TeleGramma::BotAction::Listen::VERSION = '0.13';
+$App::TeleGramma::BotAction::Listen::VERSION = '0.14';
 # ABSTRACT: Base class for bot actions that listen
 
 use Mojo::Base 'App::TeleGramma::BotAction';
@@ -45,15 +45,15 @@ App::TeleGramma::BotAction::Listen - Base class for bot actions that listen
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 AUTHOR
 
-Justin Hawkins <justin@eatmorecode.com>
+Justin Hawkins <justin@hawkins.id.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Justin Hawkins <justin@eatmorecode.com>.
+This software is copyright (c) 2019 by Justin Hawkins <justin@eatmorecode.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
