@@ -1,5 +1,5 @@
 package App::TeleGramma::Config;
-$App::TeleGramma::Config::VERSION = '0.13';
+$App::TeleGramma::Config::VERSION = '0.14';
 # ABSTRACT: TeleGramma and TeleGramma plugin configuration
 
 use Mojo::Base -base;
@@ -100,15 +100,15 @@ App::TeleGramma::Config - TeleGramma and TeleGramma plugin configuration
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 AUTHOR
 
-Justin Hawkins <justin@eatmorecode.com>
+Justin Hawkins <justin@hawkins.id.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Justin Hawkins <justin@eatmorecode.com>.
+This software is copyright (c) 2019 by Justin Hawkins <justin@eatmorecode.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
