@@ -1,5 +1,5 @@
 package App::TeleGramma::Constants;
-$App::TeleGramma::Constants::VERSION = '0.13';
+$App::TeleGramma::Constants::VERSION = '0.14';
 # ABSTRACT: Constants for TeleGramma
 
 use strict;
@@ -36,15 +36,15 @@ App::TeleGramma::Constants - Constants for TeleGramma
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 AUTHOR
 
-Justin Hawkins <justin@eatmorecode.com>
+Justin Hawkins <justin@hawkins.id.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Justin Hawkins <justin@eatmorecode.com>.
+This software is copyright (c) 2019 by Justin Hawkins <justin@eatmorecode.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
